from __future__ import unicode_literals
from scarlet.cms import views


class PostsListView(views.ListView):
    paginate_by = 100

    def __init__(self, *args, **kwargs):
        super(PostsListView, self).__init__(*args, **kwargs)



from __future__ import unicode_literals

# imports for backwards compatibility
from django.views.generic.edit import ModelFormMixin

from .base_views import BaseView, SiteView, CMSView, ModelCMSView, ModelCMSMixin
from .list import ListView
from .item import FormView, PreviewWrapper, VersionsList
from .actions import PublishView, UnPublishView, DeleteView



from __future__ import unicode_literals
from django.apps import AppConfig as DjangoAppConfig


class AppConfig(DjangoAppConfig):
    name = "scarlet.cms"

    def ready(self):
        super(AppConfig, self).ready()
        self.module.autodiscover()



from __future__ import unicode_literals
from django.dispatch import Signal


# Signal sent after a file is saved into filesystem.
# sender is the file path
file_saved = Signal()
file_removed = Signal()
